@@ -6,13 +6,13 @@
 #
 from struct import pack_into
 
+from moldudp.msg.msgpub import MsgPublisher
 from moldudp.codec.const import HEADER_SIZE
 from moldudp.codec.const import MESSAGE_SIZE_FIELD_LEN
 from moldudp.codec.const import MOLDPKT_SIZE
 from moldudp.codec.const import PAYLOAD_OFFSET
 from moldudp.codec.const import PAYLOAD_SIZE
 from moldudp.codec.const import SESSION_OFFSET
-from moldudp.codec.msgpub import MsgPublisher
 
 
 class MoldUDPEncoder:
